Installation — MARV Robotics 3.3.5 documentation

# Installation

There are currently two modes of installation. One is based on Docker the other installs MARV Robotics natively on your system and assume ROS to be installed natively as well. It might be a good idea to read both and decide then.

- Docker
  - Prerequisites
  - Building or configure image used
  - Start container
  - Adding your own code
  - Serve documentation
  - Summary
- Native
  - Prerequisites
  - Robot Operating System
  - MARV Robotics
  - Build and serve documentation
  - Summary